==> presentation-0.0.4.tar.gz: lib/src/effects/reveal_effect.dart <==
import 'package:flutter/material.dart';
import 'package:presentation/src/widgets/animation_builder.dart';

class RevealEffect extends StatefulWidget {
  const RevealEffect({
    Key key,
    this.child,
    this.offset = const Offset(0, 0),
  }) : super(key: key);

  final Widget child;
  final Offset offset;

  @override
  _RevealEffectState createState() => _RevealEffectState();
}

class _RevealEffectState extends State<RevealEffect>
    with SingleTickerProviderStateMixin {
  AnimationController _controller;

  @override
  void initState() {
    _controller = AnimationController(
      vsync: this,
      duration: Duration(seconds: 2),
    )..forward();
    super.initState();
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return WrappedAnimatedBuilder<double>(
      animation: _controller,
      builder: (_, animation, child) {
        return ClipOval(
          clipper: _CircleRect(animation.value, offset: widget.offset),
          child: child,
        );
      },
      child: Align(
        alignment: Alignment.center,
        child: widget.child,
      ),
    );
  }
}

class _CircleRect extends CustomClipper<Rect> {
  const _CircleRect(
    this.factor, {
    this.offset,
  });

  final double factor;
  final Offset offset;

  @override
  Rect getClip(Size size) {
    final newSize = size.longestSide * 2 * factor * 1.3;
    return fromCenter(
      center: Offset(size.width * offset.dx, size.height * offset.dy),
      width: newSize,
      height: newSize,
    );
  }

  // TODO Replace this with dart version when available in beta
  static Rect fromCenter({Offset center, double width, double height}) =>
      Rect.fromLTRB(
        center.dx - width / 2,
        center.dy - height / 2,
        center.dx + width / 2,
        center.dy + height / 2,
      );

  @override
  bool shouldReclip(_CircleRect oldClipper) => true;
}

==> presentation-0.0.9.tar.gz: lib/src/effects/reveal_effect.dart <==
import 'package:flutter/material.dart';
import 'package:presentation/src/widgets/animation_builder.dart';

class RevealEffect extends StatefulWidget {
  const RevealEffect({
    Key key,
    this.child,
    this.offset = const Offset(0, 0),
  }) : super(key: key);

  final Widget child;
  final Offset offset;

  @override
  _RevealEffectState createState() => _RevealEffectState();
}

class _RevealEffectState extends State<RevealEffect>
    with SingleTickerProviderStateMixin {
  AnimationController _controller;

  @override
  void initState() {
    _controller = AnimationController(
      vsync: this,
      duration: const Duration(seconds: 2),
    )..forward();
    super.initState();
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return WrappedAnimatedBuilder<double>(
      animation: _controller,
      builder: (_, animation, child) {
        return ClipOval(
          clipper: _CircleRect(animation.value, offset: widget.offset),
          child: child,
        );
      },
      child: Align(
        alignment: Alignment.center,
        child: widget.child,
      ),
    );
  }
}

class _CircleRect extends CustomClipper<Rect> {
  const _CircleRect(
    this.factor, {
    this.offset,
  });

  final double factor;
  final Offset offset;

  @override
  Rect getClip(Size size) {
    final newSize = size.longestSide * 2 * factor * 1.3;
    return fromCenter(
      center: Offset(size.width * offset.dx, size.height * offset.dy),
      width: newSize,
      height: newSize,
    );
  }

  // TODO Replace this with dart version when available in beta
  static Rect fromCenter({Offset center, double width, double height}) =>
      Rect.fromLTRB(
        center.dx - width / 2,
        center.dy - height / 2,
        center.dx + width / 2,
        center.dy + height / 2,
      );

  @override
  bool shouldReclip(_CircleRect oldClipper) => true;
}
